# Brown Dwarf Simulation Code
MASS FETCH:
- **Name: mass_f(x, m1, m2, alpha)**<br>
    **Quick Look**: Returns a Inverse Mass CDF Value for a given random value, with parameters of maximum and minimum mass, as well as a given power.
    Called exclusively by inverse_power()<br>
    **Inputs**:<br>
    (float) x - random value between 0 and 1, including 0, generated by random.random()<br>
    (float) m1 - low mass cutoff<br>
    (float) m2 - high mass cutoff<br>
    (float) alpha - power law exponent<br>
    **Outputs**:<br>
    (float) - Inverse Mass CDF Value [Solar Masses]<br>
- N**ame: inverse_power(alpha, n)**<br>
    Quick Look: Returns a list of lists of Inverse Mass CDF Values for a given integer as well as a given power, each list with a differing low mass cutoff.
    Called exclusively by main()<br>
    **Inputs**:<br>
    (int) n - number of samples in each list<br>
    (float) alpha - power law exponent<br>
    **Outputs**:<br>
    (List) - 3 Lists of Inverse Mass CDF Values [Solar Masses]<br>
**AGE FETCH**:
- **Name: constf(x, a1, a2)**<br>
    Quick Look: Returns a Constant Inverse Age CDF Value for a given random value, with parameters of maximum and minimum age.
        Called by const_time_inverse_cdf(), late_burst_inverse(), and late_const_time_inverse_cdf().<br>
    **Inputs**:<br>
    (float) x - random value between 0 and 1, including 0, generated by random.random()<br>
    (float) a1 - low age cutoff<br>
    (float) a2 - high age cutoff<br>
    **Outputs**:<br>
    (float) - Constant Inverse Age CDF Value [Unit: Gyr]<br>
- **Name: const_time_inverse_cdf(n)**<br>
    **Quick Look**: Returns a list Constant Inverse Age CDF Values for a given integer.
    Called exclusively by main()<br>
    **Inputs**:<br>
    (int) n - number of samples in each list<br>
    **Outputs**:<br>
    (List) - Constant Inverse Age CDF Values [Gyr]<br>
- **Name: ins_f(x, m, b)**<br>
    **Quick Look**: Returns an Inside Out Inverse Age CDF Value for a given random value, with parameters of maximum and minimum age.
        Called by inside_out_time_inverse(), and late_burst_inverse().<br>
    **Inputs**:<br>
    (float) x - random value between 0 and 1, including 0, generated by random.random()<br>
    (float) m - slope of approximating line for inside out function (set in inside_out_time_inverse() and late_burst_inverse() as 0.03)<br>
    (float) b - y-intercept of approximating line for inside out function (set in inside_out_time_inverse() and late_burst_inverse() as 0.36)<br>
    **Outputs**:<br>
    (float) - Constant Inverse Age CDF Value [Gyr]<br>
- **Name: inside_out_time_inverse(n)**<br>
    **Quick Look**: Returns a list Inside Out Inverse Age CDF Values for a given integer.
        Called exclusively by main()<br>
    **Inputs**:<br>
    (int) n - number of samples in each list<br>
    **Outputs**:<br>
    (List) - Inside Out Inverse Age CDF Values<br>
- **Name: late_burst_inverse(n)**<br>
    Quick Look: Returns a list Late Burst Inverse Age CDF Values for a given integer. Calls ins_f() and constf() since the late burst is a mixture of both.
        Called exclusively by main()<br>
    **Inputs**:<br>
    (int) n - number of samples in each list<br>
    **Outputs**:<br>
    (List) - Late Burst Inverse Age CDF Values<br>
- **Name: late_const_time_inverse_cdf(n)**<br>
   ** Quick Look**: Returns a list Constant Inverse Age CDF Values for a given integer, between 8 and 10 Gyr of age. Calls constf().
        Called exclusively by main()<br>
    **Inputs**:<br>
    (int) n - number of samples in each list<br>
    **Outputs**:<br>
    (List) - Constant Inverse Age CDF Values [Gyr]<br>
**MODEL FETCH**:<br>
- **Name: get_sonora()**<br>
    **Quick Look**: Returns a list of lists of the reference values for age, mass, and temperatures based on the Sonora evolutionary model.
    Output:<br>
    (List) - 3 Lists of age, mass, and temperature respectively of the reference values from the source file, "nc+0.0_co1.0_age.txt".<br>
- **Name: get_2008()**<br>
    **Quick Look**: Returns a list of lists of the reference values for age, mass, and temperatures based on the Saumon & Marley 2008 evolutionary model.<br>
    **Output**:<br>
    (List) - 3 Lists of age, mass, and temperature respectively of the reference values from the source file, "sm_hybrid_age.txt".<br>
- **Name: get_baraffe()<br>**
    **Quick Look**: Returns a list of lists of the reference values for age, mass, and temperatures based on the Baraffe evolutionary model.<br>
    **Output**:<br>
    (List) - 3 Lists of age, mass, and temperature respectively of the reference values from the source file, "baraffe.txt".<br>

